@@ -88,6 +88,13 @@ def handle_db_id(data_dict: dict) -> dict:
             else:
                 data_dict['_id'] = data_dict['id']
             del data_dict['id']
+        # 处理批量操作时，字符串类型ID问题
+        if isinstance(data_dict['_id'], dict):  # id是列表
+            for key, value in data_dict['_id'].items():
+                if isinstance(value, list):  # 查找ID是列表
+                    for i in range(len(value)):
+                        if isinstance(value[i], str):  # 是字符串
+                            data_dict['_id'][key][i] = ObjectId(str(value[i]))
         return data_dict
     except Exception as err:
         handle_abnormal(
